=========
 Changes
=========


0.0.1 (2020-06-19)
==================

- First PyPI release.

- The weak ref classes no longer have dictionaries for arbitrary
  attributes. They never persisted arbitrary attributes.
